==> mktcenter-service-1.0.0-vg-20220214.071644-46-sources.jar: com/bizvane/mktcenterservice/interfaces/ActivityManualService.java <==
package com.bizvane.mktcenterservice.interfaces;


import com.bizvane.centerstageservice.models.po.SysCheckPo;
import com.bizvane.couponfacade.models.vo.CouponDetailResponseVO;
import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.mktcenterservice.models.bo.ActivityBO;
import com.bizvane.mktcenterservice.models.po.MktActivityPOWithBLOBs;
import com.bizvane.mktcenterservice.models.vg.VGActivityVo;
import com.bizvane.mktcenterservice.models.vo.ActivityManualVO;
import com.bizvane.mktcenterservice.models.vo.ActivityVO;
import com.bizvane.mktcenterservice.models.vo.PageForm;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;
import com.github.pagehelper.PageInfo;

import java.text.ParseException;
import java.util.ArrayList;
import java.util.List;


public interface ActivityManualService {

  ResponseData<ActivityVO> getActivityManualList(ActivityVO vo , PageForm pageForm,SysAccountPO stageUser);

  ResponseData<Integer> addActivityManual(ActivityBO bo,SysAccountPO stageUser);

  ResponseData<Integer> updateActivityManual(ActivityBO bo, SysAccountPO stageUser);

  ResponseData<ActivityManualVO> executeActivity(ActivityManualVO vo);

  ResponseData<ActivityManualVO> executeActivityScanVG(ActivityManualVO vo);

  ResponseData<ActivityManualVO> executeActivityVGV2(ActivityManualVO vo);

  ResponseData<ActivityManualVO> subscribeActivityVG(ActivityManualVO vo);

  ResponseData<List<ActivityBO>> getActivityManualEffect(ActivityVO vo);

  ResponseData<ActivityBO> selectActivityManualByBusinessCode(String businessCode);

  ResponseData<List<ActivityVO>>  getActivityByMemberInfo(MemberInfoModel memberInfoModel,Integer activityType);

  ResponseData<ArrayList<ActivityVO>>  getActivityByQrcode(MemberInfoModel memberInfoModel, String activityCode, Integer activityType);

  ResponseData<Integer>  checkActivity(SysCheckPo po, SysAccountPO sysAccountPO);

  ResponseData validateActivity(ActivityManualVO vo);

  ResponseData<List<ActivityVO>>  getActivityByMemberInfoVg(MemberInfoModel memberInfoModel, Integer activityType);

  ResponseData<ArrayList<ActivityVO>>  getActivityByQrcodeVg(MemberInfoModel memberInfoModel, String activityCode, Integer activityType);

  ResponseData<List<VGActivityVo>>  getActivityByMemberInfoVgV2(ActivityManualVO vo);

  ResponseData<ArrayList<VGActivityVo>>  getActivityByQrcodeVgV2(ActivityManualVO vo);


}

==> mktcenter-service-1.5.3-vg-20221108.085411-15-sources.jar: com/bizvane/mktcenterservice/interfaces/ActivityManualService.java <==
package com.bizvane.mktcenterservice.interfaces;


import java.util.ArrayList;
import java.util.List;

import com.bizvane.centerstageservice.models.po.SysCheckPo;
import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.mktcenterservice.models.bo.ActivityBO;
import com.bizvane.mktcenterservice.models.vg.VGActivityVo;
import com.bizvane.mktcenterservice.models.vo.ActivityManualVO;
import com.bizvane.mktcenterservice.models.vo.ActivityVO;
import com.bizvane.mktcenterservice.models.vo.PageForm;
import com.bizvane.utils.responseinfo.ResponseData;
import com.bizvane.utils.tokens.SysAccountPO;


public interface ActivityManualService {

  ResponseData<ActivityVO> getActivityManualList(ActivityVO vo , PageForm pageForm,SysAccountPO stageUser);

  ResponseData<Integer> addActivityManual(ActivityBO bo,SysAccountPO stageUser);
  
  int addActivityQRcode(List<Long> idList, SysAccountPO stageUser);

  ResponseData<Integer> updateActivityManual(ActivityBO bo, SysAccountPO stageUser);

  ResponseData<ActivityManualVO> executeActivity(ActivityManualVO vo);

  ResponseData<ActivityManualVO> executeActivityScanVG(ActivityManualVO vo);

  ResponseData<ActivityManualVO> executeActivityVGV2(ActivityManualVO vo);

  ResponseData<ActivityManualVO> subscribeActivityVG(ActivityManualVO vo);

  ResponseData<List<ActivityBO>> getActivityManualEffect(ActivityVO vo);

  ResponseData<ActivityBO> selectActivityManualByBusinessCode(String businessCode);

  ResponseData<List<ActivityVO>>  getActivityByMemberInfo(MemberInfoModel memberInfoModel,Integer activityType);

  ResponseData<ArrayList<ActivityVO>>  getActivityByQrcode(MemberInfoModel memberInfoModel, String activityCode, Integer activityType);

  ResponseData<Integer>  checkActivity(SysCheckPo po, SysAccountPO sysAccountPO);

  ResponseData validateActivity(ActivityManualVO vo);

  ResponseData<List<ActivityVO>>  getActivityByMemberInfoVg(MemberInfoModel memberInfoModel, Integer activityType);

  ResponseData<ArrayList<ActivityVO>>  getActivityByQrcodeVg(MemberInfoModel memberInfoModel, String activityCode, Integer activityType);

  ResponseData<List<VGActivityVo>>  getActivityByMemberInfoVgV2(ActivityManualVO vo);

  ResponseData<ArrayList<VGActivityVo>>  getActivityByQrcodeVgV2(ActivityManualVO vo);


}
